# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGatewaysResult',
    'AwaitableGetGatewaysResult',
    'get_gateways',
    'get_gateways_output',
]

@pulumi.output_type
class GetGatewaysResult:
    """
    A collection of values returned by getGateways.
    """
    def __init__(__self__, environment=None, filter=None, gateways=None, id=None):
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if filter and not isinstance(filter, dict):
            raise TypeError("Expected argument 'filter' to be a dict")
        pulumi.set(__self__, "filter", filter)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetGatewaysEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def filter(self) -> Optional['outputs.GetGatewaysFilterResult']:
        return pulumi.get(self, "filter")

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Sequence['outputs.GetGatewaysGatewayResult']:
        """
        (List of Object) List of Gateways. Each gateway object exports the following attributes:
        """
        return pulumi.get(self, "gateways")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetGatewaysResult(GetGatewaysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewaysResult(
            environment=self.environment,
            filter=self.filter,
            gateways=self.gateways,
            id=self.id)


def get_gateways(environment: Optional[Union['GetGatewaysEnvironmentArgs', 'GetGatewaysEnvironmentArgsDict']] = None,
                 filter: Optional[Union['GetGatewaysFilterArgs', 'GetGatewaysFilterArgsDict']] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewaysResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_gateways` describes a Gateways data source that allows you to filter and list multiple Gateways.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    all = confluentcloud.get_gateways(environment={
        "id": "env-123abc",
    })
    ready_ingress = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "gateway_types": ["AwsIngressPrivateLink"],
            "phases": ["READY"],
        })
    us_east = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "regions": ["us-east-1"],
            "display_names": ["prod-gateway-ingress-use1"],
        })
    pulumi.export("allGateways", all.gateways)
    pulumi.export("readyIngressGateways", ready_ingress.gateways)
    ```
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult).value

    return AwaitableGetGatewaysResult(
        environment=pulumi.get(__ret__, 'environment'),
        filter=pulumi.get(__ret__, 'filter'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'))
def get_gateways_output(environment: Optional[pulumi.Input[Union['GetGatewaysEnvironmentArgs', 'GetGatewaysEnvironmentArgsDict']]] = None,
                        filter: Optional[pulumi.Input[Optional[Union['GetGatewaysFilterArgs', 'GetGatewaysFilterArgsDict']]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGatewaysResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_gateways` describes a Gateways data source that allows you to filter and list multiple Gateways.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    all = confluentcloud.get_gateways(environment={
        "id": "env-123abc",
    })
    ready_ingress = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "gateway_types": ["AwsIngressPrivateLink"],
            "phases": ["READY"],
        })
    us_east = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "regions": ["us-east-1"],
            "display_names": ["prod-gateway-ingress-use1"],
        })
    pulumi.export("allGateways", all.gateways)
    pulumi.export("readyIngressGateways", ready_ingress.gateways)
    ```
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['filter'] = filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult)
    return __ret__.apply(lambda __response__: GetGatewaysResult(
        environment=pulumi.get(__response__, 'environment'),
        filter=pulumi.get(__response__, 'filter'),
        gateways=pulumi.get(__response__, 'gateways'),
        id=pulumi.get(__response__, 'id')))
